@@ -12,18 +12,17 @@ from astropy.coordinates import SkyCoord
 from astropy import wcs
 from astropy.time import Time
 
-import cdshealpix
 from .. import mocpy
 from .. import utils
 
 from .. import MOC, serializer
 from ..interval_set import IntervalSet
 
-__author__ = "Thomas Boch, Matthieu Baumann"
+__author__ = "Thomas Boch, Matthieu Baumann, François-Xavier Pineau"
 __copyright__ = "CDS, Centre de Données astronomiques de Strasbourg"
 
 __license__ = "BSD 3-Clause License"
-__email__ = "thomas.boch@astro.unistra.fr, matthieu.baumann@astro.unistra.fr"
+__email__ = "thomas.boch@astro.unistra.fr, baumannmatthieu0@gmail.com, francois-xavier.pineau@astro.unistra.fr"
 
 
 class STMOC(serializer.IO):
@@ -466,7 +465,7 @@ class STMOC(serializer.IO):
 
         return stmoc
 
-    def save(self, path, format='fits'):
+    def save(self, path, format='fits', overwrite=False):
         """
         Writes the ST-MOC to a file.
 
@@ -480,7 +479,17 @@ class STMOC(serializer.IO):
             The format in which the MOC will be serialized before being saved.
             Possible formats are "fits", "ascii" or "json".
             By default, ``format`` is set to "fits".
+        overwrite : bool, optional
+            If the file already exists and you want to overwrite it, then set the  ``overwrite`` keyword. 
+            Default to False.
         """
+        import os
+        file_exists = os.path.isfile(path)
+        
+        if file_exists and not overwrite:
+            raise OSError('File {} already exists! Set ``overwrite`` to '
+                          'True if you want to replace it.'.format(path))         
+        
         if format == 'fits':
             mocpy.coverage_2d_to_fits_file(path, self.__index)
         elif format == 'ascii':
@@ -490,7 +499,7 @@ class STMOC(serializer.IO):
         else:
             formats = ('fits', 'ascii', 'json')
             raise ValueError('format should be one of %s' % (str(formats)))
-
+            
     @classmethod
     def load(cls, path, format='fits'):
         """
